import { Logger } from "winston"

import NetToolBase, { NetError } from "../netTool/base"

class LarkBaseService extends NetToolBase {
  constructor(getToken: () => Promise<string>, logger?: Logger) {
    super({
      prefix: "https://open.f.mioffice.cn/open-apis",
      logger,
      getHeaders: async () => ({
        Authorization: `Bearer ${await getToken()}`,
      }),
    })
  }

  protected async request<T = any>(params: any): Promise<T> {
    return super.request<T>(params).catch((error: NetError) => {
      const res = {
        httpStatus: error.response?.status,
        code: error.code,
        data: error.data,
        message: error.message,
      } as T
      this.logger.error(`larkNetTool catch error: ${JSON.stringify(res)}`)
      return res
    })
  }
}

export default LarkBaseService
